package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`/@`!````L"%```````!``````````)BS````
M`````````$``.``)`$``'0`<``8````%````0`````````!``$```````$``
M0```````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"0```````.`)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````(2C````````A*,`````````
M`"````````$````&````\*T```````#PK6```````/"M8```````6`0`````
M```8%0``````````(````````@````8````(K@````````BN8```````"*Y@
M``````#P`0```````/`!````````"``````````$````!````%0"````````
M5`)```````!4`D```````$0`````````1``````````$`````````%#E=&0$
M````0)P```````!`G$```````$"<0```````]`````````#T``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````/"M````````\*U@``````#PK6``
M`````!`"````````$`(````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````(`````0`
M```4`````P```$=.50#Q\'6#=CYJ-VGA6;Y^D!)S%HJR`B4```!$````!```
M``@````@'!``!4`$ABH"0`"0A@&HPBD`($D@!`NXHCA-N@0&"D0```!%````
M````````````````1P```$D```!*`````````$L```!,````3@```$\```!0
M````40````````!3``````````````!4````50```%@``````````````%D`
M``!;````7````%X`````````8````&(``````````````&0```!E````9@``
M``````#)U;)QSMY'+:/@^TGJT^\.I]VC:R_%F[;;S>.>A_F<@5:DFY9K"4/6
M.?*+'`TZEPO%B060#!3BGHD'<-,A_^0."XH05VI_FGRR`8MOQ;F<0'^IG)MN
MQ=\?V7%8'+OCDGRL2^/`U634?."G`@HS8MOM>O!*:V>OS&9"1=7LXT?&`7U!
MCL7#Y3\L\MO3'?JA;&"YC?$.````````````````````````````````/0$`
M`!(`````````````````````````(0(``!(`````````````````````````
MH`(``!(`````````````````````````=0(``!(`````````````````````
M````$0```"``````````````````````````IP(``!(`````````````````
M````````+`,``!(`````````````````````````TP```!(`````````````
M````````````O`(``!(`````````````````````````%`,``!(`````````
M````````````````#`,``!(`````````````````````````KP```!(`````
M````````````````````Y0,``!(`````````````````````````.`$``!(`
M````````````````````````V`(``!(`````````````````````````R@(`
M`!(`````````````````````````CP(``!(`````````````````````````
M)0,``!(`````````````````````````20,``!(`````````````````````
M````H0$``!(`````````````````````````80$``!(`````````````````
M````````X0```!(`````````````````````````ZP$``!(`````````````
M````````````3@(``!(`````````````````````````A@(``!(`````````
M````````````````B`$``!(`````````````````````````7@(``!(`````
M````````````````````?0(``!(`````````````````````````V`$``!(`
M````````````````````````M0(``!(`````````````````````````'`(`
M`!(`````````````````````````?@,``!(`````````````````````````
M=P,``!(`````````````````````````;P$``!(`````````````````````
M````/`,``!(`````````````````````````+0```"``````````````````
M````````[`(``!(`````````````````````````>````!(`````````````
M````````````#P$``!(`````````````````````````.@(``!(`````````
M````````````````Y`$``!(`````````````````````````O@```!(`````
M````````````````````E@$``!(`````````````````````````:@```!(`
M````````````````````````0@$``!(`````````````````````````\P(`
M`!(`````````````````````````S0$``!(`````````````````````````
M'`$``!(`````````````````````````K0(``!(`````````````````````
M````%0(``!(`````````````````````````:`,``!(`````````````````
M````````4`,``!(`````````````````````````KP$``!(`````````````
M````````````<`,``!(`````````````````````````PP(``!(`````````
M````````````````/````"``````````````````````````\P```!(`````
M````````````````````-0,``!(`````````````````````````?P$``!(`
M`````````````````````````0,``!(`````````````````````````<`(`
M`!(`````````````````````````,@(``!(`````````````````````````
MW@(``!(`````````````````````````AP```!(`````````````````````
M````4````"``````````````````````````T0(``!(`````````````````
M````````6@,``!(`````````````````````````3@$``!(```#0'4``````
M````````````$P0``!(`#@#024````````0,````````;`0``!(`#@#P14``
M`````-L!````````O`,``!(`#P`T6T``````````````````D@,``"$`&@"(
MLF````````@`````````P@,``!(`#@#P0D````````4`````````4@0``!(`
M#@#`6D```````&4`````````G@```!(```"`'D``````````````````+0$`
M`!$`&@!@LF````````0`````````(`0``!``&0`HLF``````````````````
M'@,``!$`&@#`LF````````@`````````(@0``"``&0`HLF``````````````
M````D0,``"$`&@"(LF````````@`````````L@,``!(`#@`P6T````````(`
M````````8@0``!$`&0!`LF````````@`````````@00``!(`#@``0T``````
M`,H!`````````@$``!$`&@"`LF````````$`````````BP,``!(`#@!@'T``
M`````$4"````````H`0``!(`#@#01T```````'D`````````D`,``!$`&@"(
MLF````````@`````````TP,``!(`#@!02$```````"0`````````[@,``!(`
M#@#@64```````&\`````````H0,``!``&@!(LF``````````````````K0,`
M`!``&@`(PV``````````````````+00``!$`$`!`6T````````0`````````
MR@0``!(`#@#@54```````/@#````````/`0``!(`#@`P0D```````+D`````
M````)@0``!(`#@"P(4```````"H`````````O0$``!(```"P&T``````````
M````````!P0``!(`#@``14```````.D`````````F@,``!``&0!(LF``````
M````````````^@,``!(`#@#01$```````"0`````````K@0``!(`#@!06D``
M`````#H`````````>00``!(`#@"P04```````"H`````````]@$``!$`&@"0
MLF```````!,`````````C@0``!(`#@"`2$```````$H!````````>P0``!(`
M"P#X&D```````````````````&QI8G!E<FPN<V\N-2XR,`!?251-7V1E<F5G
M:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R
M0VQA<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E
M<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L
M7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT
M97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S
M971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L
M86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F
M;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L
M7W)U;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!0
M97)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?
M<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T
M:')E860N<V\N,`!O<&5N-C0`<F5A9`!?7V5R<FYO7VQO8V%T:6]N`&QS965K
M-C0`<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!L:6)C+G-O+C8`7U]R96=I
M<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?
M<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E
M='!I9`!S=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK
M`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS
M=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?
M8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C
M8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T
M80!?7V)S<U]S=&%R=`!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N
M=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A
M7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?
M7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!X<U]I;FET
M`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N
M`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`1TQ)0D-?,BXR+C4`1TQ)0D-?,BXQ-`!'3$E"0U\R+C,N-`!'3$E"
M0U\R+C,N,@!'3$E"0U\R+C0``````@`#``(``@````(``@````(``@`"````
M`@````(``@`$``(``@````````````,``@````4``@````(``P`"``(````&
M````!P```````P`"````````````!@```````@`#``(``@````(``@``````
M`@````(``@`#``8```````(`!@````$``0`!``(``0`!```````!``(``0`"
M``$``0`!`````0`!``(``0`!``$``0`!``$``0`!`````0`!``$``0`!````
M`0`!```````!``$`!0(``!`````@````=1II"0```P#@!`````````$`!0!4
M`@``$`````````"4D98&```'`.P$```0````=!EI"0``!@#W!```$````'(9
M:0D```4``P4``!`````4:6D-```$``\%```0````=1II"0```@#@!```````
M`/BO8```````!@```"0``````````````&"R8```````!0```$P`````````
M`````("R8```````!0```%0``````````````(BR8```````!0```%<`````
M`````````)"R8```````!0```&8``````````````,"R8```````!0```$X`
M`````````````!BP8```````!P````$``````````````""P8```````!P``
M``(``````````````"BP8```````!P````,``````````````#"P8```````
M!P````0``````````````#BP8```````!P````8``````````````$"P8```
M````!P````<``````````````$BP8```````!P````@``````````````%"P
M8```````!P````D``````````````%BP8```````!P```&``````````````
M`&"P8```````!P````H``````````````&BP8```````!P````L`````````
M`````'"P8```````!P````P``````````````'BP8```````!P````T`````
M`````````("P8```````!P````X``````````````(BP8```````!P````\`
M`````````````)"P8```````!P```!```````````````)BP8```````!P``
M`!$``````````````*"P8```````!P```!(``````````````*BP8```````
M!P```!,``````````````+"P8```````!P```!0``````````````+BP8```
M````!P```!4``````````````,"P8```````!P```!8``````````````,BP
M8```````!P```!<``````````````-"P8```````!P```!@`````````````
M`-BP8```````!P```!D``````````````."P8```````!P```!H`````````
M`````.BP8```````!P```!L``````````````/"P8```````!P```!P`````
M`````````/BP8```````!P```!T```````````````"Q8```````!P```!X`
M``````````````BQ8```````!P```!\``````````````!"Q8```````!P``
M`"```````````````!BQ8```````!P```"$``````````````""Q8```````
M!P```"(``````````````"BQ8```````!P```",``````````````#"Q8```
M````!P```"4``````````````#BQ8```````!P```"8``````````````$"Q
M8```````!P```"<``````````````$BQ8```````!P```"@`````````````
M`%"Q8```````!P```"D``````````````%BQ8```````!P```"H`````````
M`````&"Q8```````!P```"L``````````````&BQ8```````!P```$0`````
M`````````'"Q8```````!P```"P``````````````'BQ8```````!P```"T`
M`````````````("Q8```````!P```"X``````````````(BQ8```````!P``
M`"\``````````````)"Q8```````!P```#```````````````)BQ8```````
M!P```#$``````````````*"Q8```````!P```#(``````````````*BQ8```
M````!P```#,``````````````+"Q8```````!P```#0``````````````+BQ
M8```````!P```#4``````````````,"Q8```````!P```$L`````````````
M`,BQ8```````!P```#8``````````````-"Q8```````!P```#<`````````
M`````-BQ8```````!P```#D``````````````."Q8```````!P```#H`````
M`````````.BQ8```````!P```#L``````````````/"Q8```````!P```#P`
M`````````````/BQ8```````!P```#T```````````````"R8```````!P``
M`#X```````````````BR8```````!P```#\``````````````!"R8```````
M!P```$```````````````!BR8```````!P```$(``````````````""R8```
M````!P```$,``````````````$B#[`A(BP7UE"``2(7`=`7H0P0``$B#Q`C#
M``````````````````#_->*4(`#_)>24(``/'T``_R7BE"``:`````#IX/__
M__\EVI0@`&@!````Z=#_____)=*4(`!H`@```.G`_____R7*E"``:`,```#I
ML/____\EPI0@`&@$````Z:#_____);J4(`!H!0```.F0_____R6RE"``:`8`
M``#I@/____\EJI0@`&@'````Z7#_____):*4(`!H"````.E@_____R6:E"``
M:`D```#I4/____\EDI0@`&@*````Z4#_____)8J4(`!H"P```.DP_____R6"
ME"``:`P```#I(/____\E>I0@`&@-````Z1#_____)7*4(`!H#@```.D`____
M_R5JE"``:`\```#I\/[___\E8I0@`&@0````Z>#^____)5J4(`!H$0```.G0
M_O___R52E"``:!(```#IP/[___\E2I0@`&@3````Z;#^____)4*4(`!H%```
M`.F@_O___R4ZE"``:!4```#ID/[___\E,I0@`&@6````Z8#^____)2J4(`!H
M%P```.EP_O___R4BE"``:!@```#I8/[___\E&I0@`&@9````Z5#^____)1*4
M(`!H&@```.E`_O___R4*E"``:!L```#I,/[___\E`I0@`&@<````Z2#^____
M)?J3(`!H'0```.D0_O___R7RDR``:!X```#I`/[___\EZI,@`&@?````Z?#]
M____)>*3(`!H(````.G@_?___R7:DR``:"$```#IT/W___\ETI,@`&@B````
MZ<#]____)<J3(`!H(P```.FP_?___R7"DR``:"0```#IH/W___\ENI,@`&@E
M````Z9#]____);*3(`!H)@```.F`_?___R6JDR``:"<```#I</W___\EHI,@
M`&@H````Z6#]____)9J3(`!H*0```.E0_?___R62DR``:"H```#I0/W___\E
MBI,@`&@K````Z3#]____)8*3(`!H+````.D@_?___R5ZDR``:"T```#I$/W_
M__\E<I,@`&@N````Z0#]____)6J3(`!H+P```.GP_/___R5BDR``:#````#I
MX/S___\E6I,@`&@Q````Z=#\____)5*3(`!H,@```.G`_/___R5*DR``:#,`
M``#IL/S___\E0I,@`&@T````Z:#\____)3J3(`!H-0```.F0_/___R4RDR``
M:#8```#I@/S___\E*I,@`&@W````Z7#\____)2*3(`!H.````.E@_/___R4:
MDR``:#D```#I4/S___\E$I,@`&@Z````Z4#\____)0J3(`!H.P```.DP_/__
M_R4"DR``:#P```#I(/S___\E^I(@`&@]````Z1#\____)?*2(`!H/@```.D`
M_/___R7JDB``:#\```#I\/O___\EXI(@`&A`````Z>#[____)=J2(`!H00``
M`.G0^____R6BD"``9I```````````%-(@^PPB7PD'$B)="002(U\)!Q(B50D
M"$B-="002(U4)`AD2(L$)2@```!(B40D*#'`Z-G]__^ZT!U``+^`'D``2(G6
MZ.<Z``"`/="2(```=2_HV?S__TB%P$B)!3^C(``/A-0!``!(B<?H$?S__XL]
MBY(@`.BV_?__QH!%"````(L]>9(@`.BD_?__@(AB!````HL]9Y(@`.B2_?__
M@(AB!````8M$)!R->`5(8_](A?\/B!4!``!F#^_`\D@/*L?R#U@%!WP``&8/
M+@4'?```#X<J`0``2,'G`^BP_/__2(M\)!!(B06<HB``O@4```#'!96B(``$
M````2(L72(/'"$C'0`@?74``2,=`&")=0`!(B1!(BQ7$D2``2(E0$(M4)!R#
M^@&-2@1^&@\?0`!,BP],8\:#Q@%(@\<(.<Y.B4S`^'7J2(L]4Z(@`$ACR8/"
M`TC'1,CX`````$4QP$B)P;[@04``Z$3]__^%P(G#=$M(BSTGHB``Z(+[__](
MC70D)#'`O^-;0`#H\1@``$B%P'1:2(L]!:(@`.@`^___Z-O\__^)V$B+7"0H
M9$@S'"4H````=7](@\0P6\-(BSW<H2``Z*?]__^)P^NE2(GX2(GZ9@_OP$C1
MZ(/B`4@)T/)(#RK`\@]8P.G3_O__2(L]HZ$@`$B%_W08Z($X``#KD[Z0LF``
MOY-;0``QP.@^_/__2(UT)"2_F%M``.A?&```2(7`2(G'2(D%:J$@``^$8/__
M_^O$Z)7Z__^_`0```.A+_?__9BX/'X0``````)`Q[4F)T5Y(B>)(@^3P4%1)
MQ\`P6T``2,?!P%I``$C'QV`?0`#H1_O___1F#Q]$``"X3[)@`%5(+4BR8`!(
M@_@.2(GE=ANX`````$B%P'017;](LF``_^!F#Q^$``````!=PP\?0`!F+@\?
MA```````ODBR8`!52('N2+)@`$C!_@-(B>5(B?!(P>@_2`'&2-'^=!6X````
M`$B%P'0+7;](LF``_^`/'P!=PV8/'T0``(`]89`@``!U$55(B>7H;O___UW&
M!4Z0(``!\\,/'T``OP"N8`!(@S\`=07KDP\?`+@`````2(7`=/%52(GE_]!=
MZ7K___]F+@\?A```````05=!5DB-=SA!54%455-(@>R8`@``9$B+!"4H````
M2(F$)(@"```QP$R-C"2`````2(GA#Q]$``"+%DB+!DB#P1!(@\8(#\J)TTB)
MPDC!ZB!(B5GP28G02,'B"$G!X!B!X@``_P!%B<!,"<))B<!(P>@H2<'H."4`
M_P``3`G"2`G02(E!^$DYR76N2(U4)&A(C;0D:`(``&8/'X0``````$B+`D@S
M0MA(@\((2#-"H$@S0I!(C0P`2,'H'T@)R(/@_TB)0A!(.?)UUDR+#TB+7R!,
MBU<03(M?&$B+;PA,B<I,B<A-B<Y(P>(%2,'H&TR)WD@)T$B)VD@#%"2)P$F)
M[$@#="0(2<'D'DG!YAY(C8P0F7F"6DR)TDPQVD@AZDB)T$PQV$B-%`%(B>E(
MP>D"20G,3(G1B=!%B>!,,<%,(<E,,=%,C:PQF7F"6DB)P4B)QDC![AM(P>$%
M2`GQ3(G.2,'N`HG)3`GV38GF3`'I23'V08G-3"'R03'43(G22`-4)!!-C;04
MF7F"6DR)ZDV)[$G![!M(P>(%3`GB28G$2,'H`DG!Y!Z)TDP)X$F)]$P!\DDQ
MQ$P#1"0808G73"'A38G\,?%)P>0%B?9-C80(F7F"6DR)^4C!Z1M,">&)R4V-
M)`A-B>A)P>T"2<'@'DB)P4T)Z$6)YDPQP4@ARDB+3"0@,<*)P$B-M#&9>8):
M3(GQ2,'I&T@!UDR)\DC!X@5("=&)R4B-%`Y,B?Y)P>\"2,'F'DR)P4P)_D&)
MU4@Q\4DAS$B+3"0H13'$18G`2(V$`9EY@EI,B>E(P>D;20'$3(GH2,'@!4@)
MR$R)\4G![@)(P>$>B<!,"?%)B?9,`>!),<Y!B<1,(?),BW0D,#'RB?9/C80&
MF7F"6DV)YDG![AM,`<)-B>!)P>`%30GP18G`20'03(GJ2<'M`DC!XAY%B<9,
M">I)B<U),=5,(>A,BVPD.#'(B<E)C;0UF7F"6DV)]4G![1M(`?!,B?9(P>8%
M3`GNB?9(`<9,B>!)P>P"2,'@'D&)]4P)X$F)U$DQQ$TAX$R+9"1`03'0B=))
MC8P,F7F"6DV)[$G![!M)`<A,B>E(P>$%3`GAB<E,`<%-B?!)P>X"2<'@'D&)
MS$T)\$F)QDTQQDPA]DR+="1(,<:)P$F-E!:9>8):38GF2<'N&T@!UDR)XDC!
MX@5,"?*)TD@!\DR)[DG![0)(P>8>08G63`GN38G%23'U3"'I3(ML)%!$,<%%
MB<!)C80%F7F"6DV)]4G![1M(`<%,B?!(P>`%3`GHB<!(`<A,B>%)P>P"2,'A
M'D&)Q4P)X4F)]$DQS$PAXDR+9"18,?*)]D^-A`29>8):38GL2<'L&TP!PDV)
MZ$G!X`5-">!%B<!)`=!,B?))P>X"2,'B'D6)Q$P)\DF)SDDQUDPA\$R+="1@
M,<B)R4F-M#:9>8):38GF2<'N&T@!\$R)YDC!Y@5,"?:)]D@!QDR)Z$G![0)(
MP>`>08GV3`GH28G523'%32'H3(ML)&A!,=")TDF-C`V9>8):38GU2<'M&TD!
MR$R)\4C!X05,">F)R4P!P4V)X$G![`))P>`>08G-30G@28G$33'$3"'F3(MD
M)'`QQHG`28V4%)EY@EI-B>Q)P>P;2`'63(GJ2,'B!4P)XHG22`'R3(GV2,'F
M'DG![@)!B=1,"?9-B<9),?9,(?%,BW0D>$0QP46)P$F-A`:9>8):38GF2<'N
M&T@!P4R)X$C!X`5,"?")P$@!R$R)Z4G![0)(P>$>08G&3`GI28GU23'-3"'J
M3(NL)(`````Q\HGV3XV$!9EY@EI-B?5)P>T;3`'"38GP2<'@!4T)Z$6)P$D!
MT$R)XDG![`)(P>(>18G%3`GB28G,23'43"'@3(ND)(@````QR(G)28VT-)EY
M@EI-B>Q)P>P;2`'P3(GN2,'F!4P)YHGV2`'&3(GP2,'@'DG![@)!B?1,"?!)
MB=9),<9-(?!,B[0DD````$$QT(G228V,#IEY@EI-B>9)P>X;20'(3(GA2,'A
M!4P)\8G)3`'!38GH2<'M`DG!X!Y!B<]-">A)B<5-,<5,(>Y,BZPDF````#'&
MB<!(`X0DH````$V-K!69>8):3(GZ2,'J&TP![DV)_4G!Y05,">J)TDR-+!9,
MB>9)P>P"2,'F'DR)PDP)YD6)[D@Q\C'13(GR2(V,"*'KV6Y,B?!(P>(%2,'H
M&T@)T(G`2(T4`4R)^4G![P)(P>$>1(G`28GP3`GY2`.$)*@```!!B=1),<B)
M]D@#M"2P````13'%38G@2<'@!4Z-K"BAZ]EN3(G@2,'H&TP)P(G`38U$!0!,
MB?!)P>X"2,'@'DP)\$F)SD6)Q4DQQHG)2`.,)+@```!$,?),C;06H>O9;DR)
M[DR)ZDC!Y@5(P>H;2`GRB=))C3063(GB2<'L`DC!XAY,">))B<1!B?9),=2)
MP$@#A"3`````13'@3HVD`:'KV6Y,B?%-B?!)P>@;2,'A!4P)P4V)Z$G![0))
MP>`>B<E-">A)B=5,`>%-,<5!B<R)TD0Q[DR-K#"AZ]EN3(G@3(GF2,'@!4C!
M[AM(`Y0DR````$@)\$R)]DG![@)(P>8>B<!,"?9-B<9,`>A),?9!B<5%B<!$
M,?%,`X0DT````$R-M`JAZ]EN3(GJ3(GI2,'I&TC!X@5("<I,B>%)P>P"2,'A
M'HG23`GA28GT3`'R23',08G6B?9$,>!(`[0DV````$V-I`"AZ]EN38GP3(GP
M2<'@!4C!Z!M,"<")P$V-!`1,B>A)P>T"2,'@'DP)Z$F)S46)Q$DQQ8G)1#'J
M3(VL%J'KV6Y,B>9,B>)(P>8%2,'J&T@)\HG228UT%0!,B?)(P>(>2`.,).``
M``!)P>X"3`GR28G&08GU23'6B<!(`X0DZ````$4Q\$Z-M`&AZ]EN3(GI38GH
M2<'H&TC!X05,"<%-B>!)P>P"2<'@'HG)30G@28G43`'Q33'$08G.B=)$,>9(
M`Y0D\````$R-I#"AZ]EN3(GP3(GV2,'N&TC!X`5("?!,B>Y)P>T"2,'F'HG`
M3`GN38G%3`'@23'U08G$18G`1#'I3(VL"J'KV6Y,B>),B>%(P>D;2,'B!4@)
MRDR)\4G![@*)TDC!X1Y,`>I,"?%,`X0D^````$F)]D&)U8GV23'.2`.T)``!
M``!$,?!-C;0`H>O9;DV)Z$R)Z$G!X`5(P>@;3`G`B<!-C00&3(G@2<'L`DC!
MX!Y,">!)B<Q%B<9),<2)R4@#C"0(`0``1#'B3(VD%J'KV6Y,B?9,B?)(P>8%
M2,'J&T@)\HG228TT%$R)ZDG![0)(P>(>3`GJ28G%08GT23'5B<!(`X0D$`$`
M`$4QZ$Z-K`&AZ]EN3(GA38G@2<'H&TC!X05,"<%-B?!)P>X"2<'@'HG)30GP
M28G63`'I33'&08G-B=)$,?9,C;0PH>O9;DR)Z$R)[DC!X`5(P>X;2`.4)!@!
M``!("?!,B>9)P>P"2,'F'HG`3`GF38G$3`'P23'T08G&18G`1#'A3`.$)"`!
M``!,C:0*H>O9;DR)\DR)\4C!Z1M(P>(%2`G*3(GI2<'M`DC!X1Z)TDP)Z4F)
M]4P!XDDQS4&)U(GV1#'H2`.T)"@!``!-C:P`H>O9;DV)X$R)X$G!X`5(P>@;
M3`G`B<!-C40%`$R)\$G![@)(P>`>3`GP28G.18G%23'&B<E$,?),C;06H>O9
M;DR)[DR)ZDC!Y@5(P>H;2`GRB=))C3063(GB2,'B'D@#C"0P`0``2<'L`DP)
MXDF)Q$&)]DDQU(G`2`.$)#@!``!%,>!-B?1.C80!H>O9;DR)\4G!Y`5(P>D;
M3`GAB<E-C20(38GH2<'M`DG!X!Y-">A)B=5$B>%-,<6)TD0Q[DF)S4B-M#"A
MZ]EN2(G(2<'E!4C!Z!M,">B)P$R-+`9,B?9)P>X"2,'F'DR)P$P)]D6)[T@)
M\$DAQ$R)P$6)P$@A\$$)Q+C<O!N/28G&3`.T)$`!``!,`?)-B?Y,`>)-B?Q)
MP>8%2<'L&TT)]$6)Y$D!U$B)RDC!XAY(P>D"18GF2`G12(GR2`G*22'52(GR
MB?9((<I!"=5(B<)(`Y0D2`$``$P!PDV)\$P!ZDV)]4G!Z!M)P>4%30GH18G`
M20'03(GZ2<'O`DC!XAY%B<5,"?I)B<])"==-(?Q)B<^)R4DAUT4)_$F)QTP#
MO"10`0``20'W2XTT/$V)[TV)[$G!YP5)P>P;30G\18GD3`'F38GT2<'N`DG!
MY!Y!B?=-"?1)B=9-">9-(?!)B=:)TDTAYD4)\$F)QDP#M"18`0``20'.2XT,
M,$V)_DV)^$G!Y@5)P>@;30GP18G`3`'!38GH2<'M`DG!X!Y!B<Y-">A-B>5-
M"<5,(>Y-B>5%B>1-(<5$">Y)B<5,`ZPD8`$``$P!ZDV)]4@!\DR)]DG!Y05(
MP>X;20GU3(G^2<'O`DC!YAY%B>U,"?Y-B<=)`=5)"?=$B>I,(?E-B<=%B<!)
M(?=$"?E)B<=,`[PD:`$``$T!_$F)UTP!X4F)U$G!YP5)P>P;30GG18G_20'/
M3(GQ2<'N`DC!X1Y%B?Q,"?%)B?9)"<Y-(?5)B?:)]DDASD4)]4F)QDP#M"1P
M`0``30'P38GF30'H38GE2<'F!4G![1M-">Y%B?9-`<9)B=!(P>H"2<'@'D6)
M]4P)PDF)R$D)T$TAQTF)R(G)22'010G'28G`3`.$)'@!``!,`<9-B>A,`?Y-
MB>])P>@;2<'G!4T)^$6)P$D!\$R)YDC!YAY)P>P"18G'20GT2(G63`GF22'V
M2(G6B=),(>9!"?9(B<9(`[0D@`$``$@!\4R)_DP!\4V)_DC![AM)P>8%20GV
M3(GN2<'M`DC!YAY%B?9,">Y-B>5)`<Y)"?5$B?%-(>A-B>5%B>1)(?5%">A)
MB<5,`ZPDB`$``$P!ZDF)S4P!PDF)R$G!Y05)P>@;30G%38GX2<'O`DG!X!Y%
MB>U-"?A)B?=)`=5-"<=$B>I-(?Y)B?>)]DTAQT4)_DF)QTP#O"20`0``30'\
M28G730'T28G62<'G!4G![AM-"?Y%B?9-`>9)B<Q(P>D"2<'D'D6)]TP)X4V)
MQ$D)S$TAY4V)Q$6)P$DAS$4)Y4F)Q$P#I"28`0``3`'F38G\3`'N38G]2<'L
M&TG!Y05-">Q%B>1)`?1(B=9(P>H"2,'F'D6)Y4@)\DB)SD@)UDDA]DB)SHG)
M2"'600GV2(G&2`.T)*`!``!,`<9-B>A,`?9-B>Y)P>@;2<'F!4T)\$6)P$D!
M\$R)_DG![P)(P>8>18G&3`G^28G720GW32'\28G7B=))(?=%"?Q)B<=,`[PD
MJ`$``$D!STN-##Q-B?=-B?1)P><%2<'L&TT)_$6)Y$P!X4V)[$G![0))P>0>
M08G/30GL28GU30GE32'H28GUB?9-(>5%">A)B<5,`ZPDL`$``$P!ZDV)_4P!
MPDV)^$G!Y05)P>@;30G%38GP18GM20'52<'N`DG!X!Y-"?!-B>9$B>I-"<9,
M(?%-B>9%B>1-(<9$"?%)B<9,`[0DN`$``$P!]DF)UD@!\4B)UDG!Y@5(P>X;
M20GV18GV20'.3(GY2<'O`DC!X1Y$B?9,"?E-B<=)"<]-(?U-B<=%B<!)(<]%
M"?U)B<=,`[PDP`$``$T!_$F)]TT![$F)]4G!YP5)P>T;30G]18GM30'E28G4
M2,'J`DG!Y!Y%B>],">))B<Q)"=1-(>9)B<R)R4DAU$4)YDF)Q$P#I"3(`0``
M30'@38G\30'P38G^2<'L&TG!Y@5-">9%B?9-`<9)B?!(P>X"2<'@'D6)]$P)
MQDF)T$D)\$TAQ4F)T(G222'P10G%28G`3`.$)-`!``!,`<%-B>!,`>E-B>5)
MP>@;2<'E!4T)Q46)[4D!S4R)^4G![P)(P>$>18GH3`GY28GW20G/32'^28GW
MB?9)(<]%"?Y(`X0DV`$``$@!T$R)PDP!\$V)QDC!ZAM)P>8%20G618GV20'&
M3(G@2<'L`DC!X!Y$B?))"<2XUL%BRDF)QTP#O"3@`0``3`'^28G/B<E-,>=%
M,?U)B==,`>Y)B=5)P><%2<'M&TT)_4V)QTG!Z`))P><>18GM30GX28G'3`.\
M).@!``!)`?5$B>Y,`?E-B>=%B>1-,<=%,?Y)B?=,`?%)B?9)P><%2<'N&TT)
M_DF)UT6)]DG!YQY)`<Y(P>H"20G72(G"2`.4)/`!``!$B?%,`>)-B<1%B<!-
M,?Q%,>5)B<Q,`>I)B<U)P>P;2<'E!4T)[$F)]4C![@))P>4>18GD3`GN28G%
M3`.L)/@!``!)`=1$B>)-`>A-B?U%B?]),?5%,>Y)B=5-`?!)B=9)P>T;2<'F
M!4T)]4F)SDC!Z0))P>8>18GM20G.2(G!2`.,)``"``!-`<5%B>A,`?E)B?>)
M]DTQ]T4Q_$V)QTP!X4V)Q$G!YP5)P>P;30GG28G42,'J`DG!Y!Y%B?])"=1(
MB<)(`Y0D"`(``$D!ST2)^4@!\DR)]D6)]DPQYD$Q]4B)SDP!ZDF)S4C![AM)
MP>4%20GU18GM20'53(G"2<'H`DC!XAY$B>Y)"=!(B<)(`Y0D$`(``$P!\DV)
MYD6)Y$TQQD4Q]TF)]DP!^DF)]TG![AM)P><%30GW28G.2,'I`DG!YAY%B?])
M"<Y(B<%(`XPD&`(``$D!UT2)^DP!X4V)Q$6)P$TQ]$4QY4F)U$P!Z4F)U4G!
M[!M)P>4%30GE18GM20'-2(GQ2,'N`DC!X1Y%B>Q("<Y(B<%(`XPD(`(``$P!
MP4V)\$6)]DDQ\$4QQTV)X$P!^4V)YTG!Z!M)P><%30G'28G02,'J`DG!X!Y%
MB?])"=!(B<)(`Y0D*`(``$D!ST2)^4P!\DF)]HGV33'&13'U28G.3`'J28G-
M2<'F!4G![1M-">Y%B?9)`=9,B>)(P>(>2<'L`D6)]4D)U$B)PD@#E"0P`@``
M2`'R3(G&18G`3#'F03'W3(GN3`'Z38GO2,'N&TG!YP5)"?=(B<Y(P>D"2,'F
M'D6)_T@)SDB)P4@#C"0X`@``20'71(GZ3`'!38G@18GD23'P13'&28G03`'Q
M28G62<'H&TG!Y@5-"<9%B?9)`<Y,B>E)P>T"2,'A'D6)\$D)S4B)P4@#C"1`
M`@``3`'A28GTB?9-,>Q%,>=-B<1,`?E-B<=)P><%2<'L&TT)YTF)U$C!Z@))
MP>0>18G_20G42(G"2`.4)$@"``!)`<]$B?E(`?),B>Y%B>U,,>9!,?9(B<Y,
M`?))B<Y(P>X;2<'F!4D)]D6)]DD!UDR)PDG!Z`)(P>(>1(GV20G02(G"2`.4
M)%`"``!,`>I-B>5%B>1-,<5%,>])B?5,`?I)B?=)P>T;2<'G!4T)_4F)STC!
MZ0))P><>18GM3`GY28G'3`.\)%@"``!)`=5$B>I-`?Q-B<=%B<!),<]%,?Y)
MB==-`?1)B=9)P><%2<'N&TT)_DF)]TC![@))P><>18GV3`G^28G'3`.\)&`"
M``!-`?1%B>9-`?A)B<^)R4DQ]T4Q_4V)]TT!Z$V)]4G!YP5)P>T;30G]28G7
M2,'J`DG!YQY%B>U,"?I)B<=,`[PD:`(``$T!Z$6)Q4P!^4F)]XGV23'713'\
M38GO3`'A38GL2<'G!4G![!M-"?Q-B?=%B>1)P><>3`'A2<'N`DT)_DF)QTP#
MO"1P`@``08G,2`.$)'@"``!$`?-(B5\@3`'^28G7B=)-,?=(`=!,B?)%,?A-
MB>=,`<9-B>!)P><%2<'H&TT)^$0!QDV)Z$G![0))P>`>30G%38G@2<'L`DPQ
MZDG!X!Y%`>LQT4B)\DT)Q$@!R$B)\4C!ZAM(P>$%`>Y%`>)("<I(B7<(3(E7
M$`'03(E?&$$!P4B+A"2(`@``9$@S!"4H````3(D/=1)(@<28`@``6UU!7$%=
M05Y!7\/H4>+__Y!(A?\/A+X```!!5T%6055!5%532(/L"$R+/8IX(`!-A?]T
M8P^V!X3`='8\/71R28G\28/$`4$/M@0DA,!T!#P]=>]!*?Q)BQ](A=MT.4F)
M]4F)_DUCY$R)_0\?@`````!,B>),B?9(B=_H$N'__X7`=0="@#PC/70O2(/%
M"$B+70!(A=MUVDB#Q`@QP%M=05Q!74%>05_#9@\?A```````13'DZZ`/'P!,
M*?U*C40C`4C!_0-!B6T`2(/$"%M=05Q!74%>05_#,<##9@\?1```4TB)^TB#
M[!!D2(L$)2@```!(B40D"#'`#Q^$``````!(C70D!#'`2(G?Z`'___](A<!T
M+DAC5"0$2(L%F'<@`$B-!-!(BU`(2(722(D0=-!(@\`(2(M0"$B%TDB)$'7P
MZ[Y(BT0D"&1(,P0E*````'4&2(/$$%O#Z`/A__\/'P!!5T%6055!5%532(GS
M2(G]2(/L&&1(BP0E*````$B)1"0(,<`QP(`^/0^4P$@!PTB)W^BYX/__2(UT
M)`1)B<1(B>\QP.AG_O__2(7`#X0.`0``2(G'28G%Z)/@__]$B>)(.=`/@]\`
M``!$BVPD!`^V10"$P`^$EP$``#P]#X2/`0``2(GHZPYF#Q^$``````"`^CUT
M"TB#P`$/MA"$TG7P*>A(BQ6O=B``18GM0HU\(`).C2SJZ+;A__](A<!)B44`
M#X1>`0``BU0D!$B+!89V(`!(C4T!2(L4T`^V10"$P(@"=1[K(&8N#Q^$````
M``!(@\$!#[9!_TB#P@&$P(@"=`0\/77JQ@(],<`/'T0```^V#`.(3`(!2(/`
M`83)=?`QP$B+="0(9$@S-"4H````#X7Y````2(/$&%M=05Q!74%>05_##Q\`
M2(/#`0^V0_])@\4!A,!!B$7_=>SKPF:03(LU\74@`$F#/@`/A*<```!,B?`Q
MTNL+#Q^$``````!$B>I(@\`(1(UJ`4B#.`!U[XUR`TAC]DC!Y@.+!0^&(`"%
MP'0S3(GWZ%/A__](A<!(B06A=2``=&Q-8_U(B<%*QT3Y"`````!$B6PD!.F<
M_O__9@\?1```2(GWQP7+A2```0```.B&X/__2(7`=#9-8_U,B?9(B<=*C13]
M`````.@;X?__2(G!2(D%274@`.NN,<#IBO[__[X0````13'MZ7;___^X____
M_^GS_O__Z,S>__]FD&8N#Q^$``````!!54%455-(@>RH````9$B+!"4H````
M2(F$))@````QP$B%_W0(@#\`2(G]=2M(BX0DF````&1(,P0E*`````^%(P$`
M`$B!Q*@```!;74%<05W#9@\?1```Z`/>__](A<!)B<1TR`\?`$R)Y^B`X/__
M2(7`2(G##X2D````@'L3+@^$L@```$B#PQ-(B>_H'M[__TB)WTF)Q>@3WO__
M08U\!0)(8__HAM___TF)V4F)Q4B)QTF)Z+E$6T``2,?"_____[X!````,<#H
M`N'__[\!````2(GB3(GNZ'+=__^#^/],B>]T$(M$)!@E`/```#T`0```=&KH
MY=S__TR)[^B]W/__3(GGZ.7?__](A<!(B<,/A67___]F#Q^$``````!,B>?H
M&-[__TB)[^APW?__Z?C^__\/'P`/MD,4A,`/A"3___\\+@^%.O___X![%0`/
MA!+____I*____P\?1```Z)O^___KE.A4W?__#Q]``%532(/L"(L]=',@`.B?
MWO__BSUI<R``2(N`X````$B+:`CHB=[__XL]4W,@``^VF*T```#H=][__TB+
M0`B#XW\/MT`@P>`'"<-FB5T"BSTM<R``Z%C>__^+/2)S(`!(BX#@````2(M8
M".A"WO__,=*^&5U``$B)Q^@CWO__BSW]<B``2(E#*.@DWO__BSWN<B``2(N`
MX````$B+6`CH#M[__TB+@#@&``"+/=%R(`!(B4,PZ/C=__^+/<)R(`!(BX#@
M````2(M8".CBW?__,=)(@[B``0```'09BSV@<B``Z,O=__](BX"``0``2(N0
MJ````(L]AW(@`$B)4SCHKMW__TB+@.````"+/7%R(`!(BT`(2,=`0`````#H
MD-W__TB+@.````"+/5-R(`!(BT`(2,=`(`````#H<MW__XL]/'(@`$B+@.``
M``!(BU@(Z%S=__](BX`X`P``2(E#2$B#Q`A;7<-F+@\?A```````4TB)^XL]
M!G(@`.@QW?__2(V0F`$``$B)WK\!````Z&W>__^%P'0),<!;PP\?1```BSW:
M<2``Z`7=__^+@+`!```E`/```#T`0```=!V+/;UQ(`#HZ-S__XN`L`$``"4`
M\```/0"@``!UO4B)W[X"````Z,G=__^%P`^4P`^VP%O##Q]$``!F+@\?A```
M````051528GT4TB)_;K_#P``OTI;0`!(@>P0$```2(GF9$B+!"4H````2(F$
M)`@0```QP.AJVO__A<!^;HU0_TACVH`\'`!T6DACV$B)VKXO````2(GGZ,?;
M__](A<!T2HL]''$@`.A'W/__2(G92(GB2(GN2(G'Z%;=__](BX0D"!```&1(
M,P0E*````'4V2('$$!```%M=05S##Q^``````(72=:4/'T``BSW2<"``Z/W;
M__],B>)(B>Y(B<?HS]K__^NWZ(C:__\/'X0``````$B#[`B+/:9P(`#HT=O_
M_[E074``NK`;0`"^65M``$B)QTB#Q`CIYMO__V8/'T0``$B#[`B+/79P(`#H
MH=O__TB)Q^BY____BSUC<"``Z([;__]!N!E=0`!%,<FZX%5``$R)P;YU6T``
M2(G'2(/$".G\V___9I!F+@\?A```````4TB!["`@``!D2(L$)2@```!(B80D
M&"```#'`Z%#9__]!N55;0`!!B<"YBEM``#'`N@$0``"^`0```$B)Y^C.W/__
MA<!X:DB-M"00$```N@`0``!(B>?H]=C__X7`2(G#>$Z->`%(8__H`]O__TB%
MP'0^2&/;2(VT)!`0``!(B<=(B=KHJ-K__\8$&`!(BY0D&"```&1(,Q0E*```
M`'452('$("```%O##Q^$```````QP.O8Z$?9__\/'X``````Z3O___^09BX/
M'X0``````$%6055!5%5)B?132(G[OYA;0`!(@>P@$```9$B+!"4H````2(F$
M)!@0```QP$B-="0,Z*GV__^^+P```$B)WTB)Q>@)V?__2(7`=#E(B=Z_H5M`
M`#'`Z-7W__](B=A(BXPD&!```&1(,PPE*`````^%4`$``$B!Q"`0``!;74%<
M05U!7L-(B=_HD]C__[ZN6T``3(GG08G%Z`/;__](A<!)B<9TIT&\EEM``$&#
MQ0&008`^`$T/1/1(A>UT$TR)]DB)[^AHV?__A<`/A*<```!,B??H2-C__XG"
M2)A!@'P&_R]U%P\?0`"#Z@%(8\)!@'P&_R]!Q@0&`'3M1`'J@?K_#P``#X]"
M____2(/L"+G/7$``0;FP6T``4TV)\+H`$```O@$````QP$B-?"0@Z`W;__^+
M/2=N(`#H4MG__TB-="0@2(V0F`$``+\!````Z&S7__^%P%I9=1V+/0!N(`#H
M*]G__XN`L`$``"4`\```/0"```!T'3'_OJY;0`#H'=K__TB%P$F)Q@^%(?__
M_^FX_O__2(U\)!"^`0```.CMV?__A<!UT$B-="00OZ%;0`#H>O;__TB-?"00
MZ"#8___IF?[__^AFU___9@\?1```#[8/2(GXA,ET&$B-5P%FD(#Y+P^V"D@/
M1,)(@\(!A,EU[O/#9I!F+@\?A```````55-(@^P(2(7_=#4/MB](B?M`A.UT
M*N@%U___2(U4`_](.=-R%.M/9@\?A```````2(/J`4@YTW1'@#HO=/+K+;\"
M````Z%;8__](A<`/A(T```"Z+@```&:)$$B#Q`A;7<-F#Q]$``"`.B]T.$B#
MZ@%(.=-R\D@YTW4J#Q]$``!`@/TO=+I(@\0(O[!;0`!;7>E*U___9BX/'X0`
M`````(`Z+W4)2(/J`4@YTW+R2"G:2(U"`D@]`!```'<C2(G>2(/"`;D`$```
MO^"R8`#H+=C__TB#Q`BXX+)@`%M=PY!(@\0(,<!;7<,/'X``````2(/L2+^R
M6T``9$B+!"4H````2(E$)#@QP$B+!1@7``!(B40D$$B+!107``!(B40D&$B+
M!1`7``!(B40D($B+!0P7``!(B40D*`^W!0@7``!FB40D,#'`Z&3T__\QP+^[
M6T``Z%CT__\QP+_#6T``Z$ST__\QP+_,6T``Z$#T__\QP+_36T``Z#3T__\Q
MP+_C6T``Z"CT__\QP+^86T``Z!ST__\QP+_O6T``Z!#T__\QP+_Y6T``Z`3T
M__\QP+\#7$``Z/CS__\QP+^A6T``Z.SS__\QP+\-7$``Z.#S__\QP+\67$``
MZ-3S__](C70D##'`OR%<0`#H\_+__TB%P'0/2(G&O_E;0``QP.@O]/__2(UT
M)`PQP+\R7$``Z,[R__](A<!T#TB)QK]$7$``,<#H"O3__TB-="0,,<"_3UQ`
M`.BI\O__2(7`=#Q(B<:_F%M``#'`Z.7S__\QP+Y[7$``O]-;0`#HU//__TB+
M1"0X9$@S!"4H````=5I(@\1(PP\?@`````!(C70D##'`OU]<0`#H5_+__TB%
MP'022(G&O^];0``QP.B3\___ZZR02(UT)"&_<%Q``+D*````\Z9UF$B-="0K
MO^];0``QP.AL\___ZX7H9=3__P\?1```2(/L&&1(BP0E*````$B)1"0(,<"+
M!4YJ(`"#^/]T&4B+3"0(9$@S#"4H````=45(@\08PP\?0`!(C70D!#'`O^];
M0`#HQ_'__TB%P'0B#[80@/HP#Y7`A-(/E<(/MM(AT(D%`6H@`.NV#Q^`````
M`#'`Z^WHY]/__P\?@`````!(@^P(Z.?3__^)Q^B0T___2(7`=`M(BP!(@\0(
MPP\?`#'`Z_1FD&8N#Q^$``````!!5T%628G^055!5$&]AUQ``%53O7U<0`!(
M@^Q89$B+!"4H````2(E$)$@QP$C'1"00AUQ``$C'1"08?5Q``$R-9"0@2,=$
M)""*7$``2,=$)"B`7$``2,=$)#"%7$``2,=$)#B77$``2,=$)$``````ZR9F
M#Q]$``!(B<?H,-;__TB%P'1C2(7M=#Q)BP0D28GM28/$"$B)Q4B-="0,,<!,
MB>_HN?#__TB%P$B)PTR)]G0%@#@`=<$QP$R)[^CO\?__2(7M=<1(BT0D2&1(
M,P0E*````'5O2(/$6%M=05Q!74%>05_##Q\`3(GWZ+#2__](B=])B<?HI=+_
M_TF-?`<"Z!O4__](@^P(2,?"_____TB)QU-)B<=!N:Y;0`!-B?"YSUQ``+X!
M````,<#HC]7__TR)_DR)[S'`Z'+Q__]86NE`____Z&;2__]F#Q]$``!!5T%6
M055!5$F)_553OYA;0`!(@>QX@0``9$B+!"4H````2(F$)&B!```QP$B-="0<
M2,=$)""N7$``2,=$)"B66T``2,=$)#``````2,=$)&!$7$``2,=$)&@]7$``
M2,=$)'"S7$``2,=$)'A:7$``2,>$)(````"[7$``2,>$)(@`````````2,=$
M)$"B7$``2,=$)$B_7$``2,=$)%``````Z&CO__](A<!T"8`X``^%2@0``#'`
MZ,/]__](A<!(B<,/A%0$``!(B=_H?]'__TB-?``!Z/72__^`.P!)B<9(B<5T
M-F8N#Q^$``````!$#[8#2(GO,<"YR%Q``$C'PO____^^`0```$B#PP%(@\4"
MZ%G4__^`.P!UU$B-;"1HOT1<0`#K%0\?A```````2(/%"$B+??A(A?]T.TB-
M="0<,<#HQ^[__TB%P$B)PW3?@#@`=-I(B<?H(O7__X7`=,Y(B=_HIM'__TB%
MP$B)PW5?9@\?1```2(M<)"!(A=L/A&(!``"`.P"]`0```'4EZ5,!```/'P!(
M8\5(BUS$($B%VP^$/P$``(/%`8`[``^$,P$``$B)W^C#]/__A<!TUTB)W^A'
MT?__2(7`2(G#=,=(B=_H=]#__TR)\8LQ2(/!!(V6__[^_O?6(?*!XH"`@(!T
MZ(G6P>X0]\*`@```#T362(UQ`D@/1,Z)UD``UDB#V0-,*?&-K`@$!```2&/M
M2(GOZ*C1__]!5FC67$``0;FP6T``28G82(G'28G$N<U<0`!(Q\+_____O@$`
M```QP.@:T___OL`!``!,B>?H/<___X/X_T%805D/A(````"+/1IF(`#H1='_
M_TB-D)@!``!,B>:_`0```.B!TO__A<`/A)$```!)BTT`2(L]3F8@`$V)X+J@
M74``O@$````QP.B*TO__,<!(BXPD:($``&1(,PPE*`````^%,`D``$B!Q'B!
M``!;74%<05U!7D%?PP\?@``````QV^GB_O__D.A[SO__1(L(08/Y$0^$;O__
M_TF+30!(BSWC92``38G@NF!=0`"^`0```#'`Z!_2__\QP.N3#Q\`BSUB92``
MZ(W0__^+@+`!```E`/```#T`0```#X5.____BSU!92``Z&S0__^+F+0!``#H
M$<___SG##X4P____BSTC92``Z$[0__^+@+`!```E_P$``#W``0``#X4/____
M2(GOZ$#0__](C70D'$B)P[^`7$``,<#H;.S__TB%P`^$TP$``$B)Q^A;S___
M28M]`$B)QNAO]?__2(7`2(G%#X2S`0``2(GOZ'O.__^#^`-^-DACT+_;7$``
MN04```!(C705_/.F=2"#^`0/A)X&``"#Z`1(F(!\!?\O#X2.!@``#Q^`````
M`#'`Z.GY__^%P'45,?9(B>_H2]#__X7`08G'#X59`0``OGM<0`"_[UM``#'`
MZ!_M___HBLW__V@974``4$C'PO____]!N;!;0`!-B>"Y]%Q``+X!````2(G?
M,<#H`-'__S'M6%KK3V8N#Q^$``````#HZ\S__X,X$75-Z$'-__^#Q0%(@^P(
M0;FP6T``:!E=0`!538G@4+D"74``2,?"_____[X!````2(G?,<#HK]#__TB#
MQ""^P`$``$B)W^C.S/__@_C_=*E,B>?H@<S__TB)WK^86T``,<#H<NS__TB)
MW^BZ^?__2(G8Z;K]__]FD$B)QTB)!"3HI/G__TB+!"1(B<?H^,W__^F;_?__
MOZ)<0`"]`0```.L7#Q^``````$ACQ8/%`4B+?,1`2(7_="M(C70D'#'`Z,3J
M__](A<!TWX`X`'3:2(G'Z++-__](A<!(B<-TRNE>^___OPT```"[IUQ``.E<
M^___9@\?1```28MM`.E$_O__N@(```!(Q\;N____B<?HE,___TB-M"1@`0``
MN@8```!$B?_HC\W__X"\)&`!````=0Z`O"1A`0``0P^$H04``#'2,?9$B?_H
M6\___[B)J\WO2,>$))`````!(T5G2,>$)*@```!V5#(02(F$))@```"X_MRZ
MF$C'A"2X`````````$B)A"2@````N/#ATL-(QX0DP`````````!(B80DL```
M`$B-A"3(````QX0D"`$```````!(B00D#Q]$``!(C;0D8`$``+H`@```1(G_
MZ./,__^%P$B)Q4&)Q0^.I@$``$B+E"2X````2&/%C0S"2#G*#X=^`0``2(N4
M),````!(P>@=2(F,)+@```!(`=!(B80DP````$ACA"0(`0``A<`/A#\!``!!
MO4````!(BPPD2(VT)&`!``!!*<5$.>U$#T[M2(T\`4UC]4R)\NBTS/__BX0D
M"`$``$0!Z(/X0(F$)`@!```/A5+___^)Z$B-O"20````1"GH08G%2(V$)&`!
M``!)`<;HRM'__V8N#Q^$``````!!@_T_#XZF`P``08/M0$2)Z,'H!HG%B40D
M#$B#Q0%(P>4&3`'U#Q\`28L62(V\))````!)@\9`2(F4),@```!)BU;(2(F4
M)-````!)BU;02(F4)-@```!)BU;82(F4).````!)BU;@2(F4).@```!)BU;H
M2(F4)/````!)BU;P2(F4)/@```!)BU;X2(F4)``!``#H*-'__TPY]76+1(MT
M)`Q!P>8&12GU2(L\)$ECU;E(````2(GNZ*/+__]$B:PD"`$``.E>_O__9@\?
M1```3(VT)&`!``#I(____P\?`$B+M"3`````2(U6`>EY_O__1(G_Z+?*__](
MBZPDN````$R+K"3`````2(GH2,'H`X/@/XU0`4B8QH0$R````("#^C@/CX\"
M``"X.````"G02&/2B<%(C804R````(/Y"`^#O@(``/;!!`^%<0,``(7)=`SV
MP0+&```/A70#``!,B>A(C;PDD````$2(K"0#`0``2,'H&$"(K"0'`0``3(V\
M)#`!``"(A"0``0``3(GH2,'H$$V-=RB(A"0!`0``3(GH3(VL)!$!``!(P>@(
MB(0D`@$``$B)Z$C!Z!B(A"0$`0``2(GH2,'H$(B$)`4!``!(B>A,B?U(P>@(
MB(0D!@$``.C9S___2(N$))````!(B<*(A"03`0``2,'J&$0/ML*(E"00`0``
M2(G"2,'J$(B4)!$!``!(B<)(BX0DF````$C!Z@B(E"02`0``2(G"B(0D%P$`
M`$C!ZAB(E"04`0``2(G"2,'J$(B4)!4!``!(B<)(BX0DH````$C!Z@B(E"06
M`0``2(G"B(0D&P$``$C!ZAB(E"08`0``2(G"2,'J$(B4)!D!``!(B<)(BX0D
MJ````$C!Z@B(E"0:`0``2(G"B(0D'P$``$C!ZAB(E"0<`0``2(G"2,'J$(B4
M)!T!``!(B<)(BX0DL````$C!Z@B(E"0>`0``2(G"B(0D(P$``$C!ZAB(E"0@
M`0``2(G"2,'J$(B4)"$!``!(B<)(P>H(B)0D(@$``.D,````#Q\`10^V10!)
M@\4!2(GO,<"YR%Q``$C'PO____^^`0```$B#Q0+H&,O__TPY]773QH0D6`$`
M``!H&5U``$%7N>5<0`"^`0```$&YL%M``$V)X$C'PO____](B=\QP.C@RO__
M65[I0/K__TV+;0A-A>T/A&SY__],B>_HI,?__TB#^`,/AEKY__])C70%_+_@
M7$``N04```#SIDD/1.WI0/G__TR)]>GQ_/__N$````!(8\HIT$B-C`S(````
MB<)T#S'`B<:#P`$YT,8$,0!R\TB-O"20````Z-;-__](C90DR````+D'````
M,<!(B=?S2*OI6_W__XG*2,<``````$C'1!#X`````$B-4`A(@^+X2"G0`<B#
MX/B#^`@/@C#]__^#X/@QR8G.@\$(.<%(QP0R`````'+OZ17]__^`O"1B`0``
M00^%4?K__X"\)&,!``!##X5#^O__@+PD9`$``$@/A37Z__^`O"1E`0``10^%
M)_K__[H"````2,?&QO___T2)_^AZR?__2(VT)&`!``"Z*0```$2)_^AUQ___
M:!E=0`!(C80D:`$``%#ICO[__V:0QP``````QT0(_`````#IC/S__S'_9HE\
M"/[I@/S__^A<QO__9I!F+@\?A```````055!5%532(/L&(L]<%P@`&1(BP0E
M*````$B)1"0(,<#HB\?__TB-="0$QH"I`````;_36T``,<#HP^/__TB%P'0)
M@#@Q#X1E`@``,<#HON___XL]*%P@`.A3Q___N0L```"Z`0```+X374``2(G'
MZ.S&__](A<`/A+0```"#/8QL(``!2(M`$$R+8"@/CI\````Q[;L!````ZS`/
M'T0``$F+=1!(BP5=;"``2&/32(L\T.B9QO__A<!U98L%3VP@`(/#`8/%`3G8
M?EN+/:];(`#HVL;__S')2&/53(GF2(G'Z*K'__](A<!T-4R+*$&+10PE``0@
M`#T`!```=**+/7Q;(`#HI\;__TR)[KD"````,=)(B<?HA<7__TB)QNN$BP7J
M:R``C5#_.>H/A#\!``"+/4E;(`#H=,;__[D#````N@$```"^&%U``$B)Q^@-
MQO__2(7`2(G#=#-(BT`0BST;6R``2(LHZ$/&__^Z&EU``$B)QTB)[N@3Q?__
M2(M#$$B+&/9##D`/A24"``"+/>Q:(`#H%\;__[D#````N@$```"^'UQ``$B)
MQ^BPQ?__2(7`2(G%=#U(C70D!#'`OZ%;0`#H-^+__TB%P$B)PP^$:P$``$B+
M11"+/:%:(`!,BR#HR<7__TB)VDB)QTR)YNB;Q/__BSV%6B``Z+#%__](C70D
M!,:`J0````"_F%M``#'`Z.CA__](A<!(B<-(B07S:B``#X25````OL`!``!(
MB<?H6,/__XU0`8/Z`78)@_@1#X64`0``2(M$)`AD2#,$)2@````/A7L!``!(
M@\086UU!7$%=PP\?A```````@_@!#XZX_O__NP$```!FD(L]^ED@`(/#`>@B
MQ?__3(GF2(G'Z!?#__\Y'7%J(`!_W^F+_O__9BX/'X0``````(!X`0`/A)C]
M___IC/W__Y!(BSU!:B``Z"3Q__](A<!(B05":B``#X3R````2(M%$$R+)2%J
M(`!(BQB+0PPE``0@`#T`!```#X61````2(M[$$R)YNC7Q?__08G$2(M%$$B+
M&(M##"4`!"``/0`$``!U2DB+4Q!(BP7;:2``1(GAOR!>0`!(BS`QP.B1Q/__
MD$B+!<%I(`"+/3-9(`!,BR!(BT402(L8Z%3$__],B>9(B=_HF>?__^F)_O__
MBST.62``Z#G$__\QTKD"````2(G>2(G'Z!?#__](B<+KF(L][%@@`.@7Q/__
MN0(```!(B<<QTDB)WNCUPO__2(G'Z4[___^+/<=8(`#H\L/__TB)WDB)Q^A'
MQ/__Z<#]__^_^%U``.CXP___Z'/"__^)P4B+!2)I(`!(B=J_2%Y``$B+,#'`
MZ-C#__\/'X0``````%532(G]2(/L".@2Z___#[802(G#A-)T&DB-0`$/'T``
M@/HO#[802`]$V$B#P`&$TG7N,<#HM^W__TB%[70<A<!T&(!]``!T$K[67$``
M2(G?Z/O$__](.=AT!TB#Q`A;7<-(@\0(2(GO6UWI(>/__Y!(@^P(BST&6"``
MZ#'#__^^_____TB)Q^A4PO__BSWN5R``Z!G#__\QTK[@/D``2(G'2(/$".F6
MQ/__9@\?1```2(T%F5<@`$B%P'042(L-C5<@`.DHPO__#Q^$```````QR>D9
MPO__9@\?A```````05=!5D&)_T%5051,C24>4R``54B-+1Y3(`!328GV28G5
M,=M,*>5(@^P(2,']`^@%P/__2(7M=!X/'X0``````$R)ZDR)]D2)_T'_%-Q(
M@\,!2#GK=>I(@\0(6UU!7$%=05Y!7\.09BX/'X0``````//#``!(@^P(2(/$
M",,````!``(`)7,O)7,`+W!R;V,O<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O
M=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S
M`"X`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"
M`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`
M4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`4$%27T%2
M1U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]4
M35!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,
M14%./0`Q`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`4TA,24)?4$%42`!5
M4T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`)7,E
M<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M
M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`"UE`"TM`````%]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``````````!P97)L>'-I
M+F,`````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E
M=')Y('EO=7(@;W!E<F%T:6]N*0H```````!5;F%B;&4@=&\@8W)E871E(&-A
M8VAE(&1I<F5C=&]R>0``````````)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL
M960@*&5R<FYO/25I*0H``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.
M1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,[
M"FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E
M;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D[
M"D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z
M('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M
M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@
M;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]
M/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^
M("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S
M:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?
M=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I
M"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^
M9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM
M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F
M)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@
M8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T
M;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PII9B`H97AI<W1S("1%3E9[4$%27T%21U9?
M,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["D!!4D=6(#T@;6%P("1%3E9[
M(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B0P
M(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*9F]R("AK97ES("5%3E8I
M('L*9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*?0I]"FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?
M<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE
M("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@
M)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\
M3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?
M<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P
M<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S
M:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X
M(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T
M(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E
M:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A
M9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B
M)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED
M>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@
M/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q
M,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD
M;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E
M860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH
M(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]
M("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*
M;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D
M8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D
M,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\
M*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E
M>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`H
M)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*:68@
M*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S
M92`D;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64["GT*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@
M*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[
M4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO
M)&)A<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PIO
M<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D
M92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PI]"F5L<V4@
M>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D
M8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@
M-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D
M9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D
M;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN
M97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]
M"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D[
M"GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N
M86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL
M96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*
M96QS92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F
M:6QE;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP
M<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L;W-E("1O=70["GT*;W!E
M;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N
M;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL
M96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S
M<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@
M>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL
M96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE
M(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP
M,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P
M87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA
M;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H
M4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U
M;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!
M4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I
M<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*
M=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R
M"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H
M:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8[
M"GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?
M:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB
M<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H
M($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@
M(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?
M87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*
M96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF
M("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E
M<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P
M96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@
M;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]
M("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[
M)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE
M<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8[
M"F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@
M*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H
M9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R
M."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO
M="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@
M)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2([
M"GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II
M<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z
M)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>
M.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN
M960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P
M87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL
M92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H
M*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I
M;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I
M;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H
M*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N
M9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(
M/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH
M/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L
M("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@
M)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I
M9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N
M('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI
M("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@
M+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*
M?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D
M8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H
M*3L*;7D@0&EN8R`]('-O<G0@>PIL96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I
M"GT@9W)E<"!["B$O0E-$4$%.+PI](&=R97`@>PHH)&)U;F1L92!N92`G<VET
M92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*
M;7D@)69I;&5S.PHO7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q
M?2LK(&9O<B!K97ES("4Z.CL*)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.
M0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY
M("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D
M;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N
M86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D
M7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I
M*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@
M*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F
M(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q
M(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*
M?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET
M=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]
M?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN
M9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B
M+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E
M;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D
M9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&
M24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II
M9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI
M>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P
M;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E
M;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS
M<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD
M>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N
M86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?
M;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C
M='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M
M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG
M97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$
M-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L
M('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R
M<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD
M8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII
M9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H
M)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A
M8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]
M"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H
M95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N
M9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H
M+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U
M:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E
M<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M
M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U
M=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@
M870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M
M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE
M;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M
M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_
M"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S
M=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@
M)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@
M)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I
M;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@
M(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B
M)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT
M<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S
M=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`
M05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM
M;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB
M(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50
M871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M
M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ
M4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A
M=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M
M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q
M=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG
M<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U
M:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@
M<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@
M?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V
M86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@
M>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]
M"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@
M/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[
M)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I
M*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I
M;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R
M;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^
M*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN
M3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L
M<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*
M96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%
M4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D
M<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B
M2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D
M14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M
M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K
M("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B
M=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@
M)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C
M='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M
M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG
M97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$
M-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L
M('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R
M<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD
M8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS
M92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@
M>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H
M*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@
M*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H
M)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!]
M(#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P
M87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D97AT+"`D
M8W)C*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD9FEL96YA;64@/2`B
M)'!A<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PIU
M;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*<'5S:"!`=&UP9FEL
M92P@)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N9&5F+"`D9FEL96YA
M;64I(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H+"`G/B<L("1F:6QE
M;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N*"1F:"P@)&9I
M;&5N86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%
M3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H
M+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII
M9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM0
M05)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]
M"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG
M+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG
M>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<
M421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O
M9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92![
M"B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G
M;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D
M(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H
M*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@
M8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_
M7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET
M7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*
M<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]
M"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]]
M.PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.
M5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES
M=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@
M(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[
M4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@
M*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@
M/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD
M14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]
M*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H
M)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT
M(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP
M=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD
M7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET
M96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA
M9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I
M;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L
M.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H
M(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O
M("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@
M)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?
M7T524D]2.PHQ.PI?7T5.1%]?"@````````````````````````#`0P$;`SOT
M````'0```.!^__]``0``((/__Z`&``!PA?__$`$``'"&__]H`0``H)W__[@!
M``!PGO__*`(``/">__]0`@``,*'__Z`"``"@HO__X`(``!"D__\0`P``H*3_
M_S`#``!PI?__:`,``*"E__^``P``\*7__Y@#``"PIO__P`,``,"F___8`P``
MD*C__S`$``#`J/__2`0``+"I__^8!```D*O__[@$```0K/__V`0``$"L___X
M!```D*W__U@%``"@N?__$`8``*"]__]0!@``$+[__X@&``!0OO__R`8``("^
M___@!@``\+[__R@'````````%``````````!>E(``7@0`1L,!PB0`0<0%```
M`!P```!8A/__*@``````````````%``````````!>E(``7@0`1L,!PB0`0``
M)````!P```"8??__,`0````.$$8.&$H/"W<(@``_&CLJ,R0B`````$P```!$
M`````(7__R\7````0@X0CP)"#AB.`T8.((T$0@XHC`5!#C"&!D$..(,'1P[0
M!0,*%PH..$$.,$$.*$(.($(.&$(.$$(."$$+````;````)0```#@F___R@``
M``!+#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=$#D`"<PH..$/##C!!
MQ@XH0LP.($+-#AA"S@X00L\."$H+7`XX0<,.,$'&#BA"S`X@0LT.&$+.#A!"
MSPX(`````"0````$`0``0)S__WT`````00X0@P)'#B`";@H.$$$."$$+````
M``!,````+`$``)B<__\T`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!
M#CB#!TH.4`,F`0H..$$.,$$.*$(.($(.&$(.$$(."$0+`````#P```!\`0``
MB)[__VP!````0@X0C0)"#AB,`T$.((8$00XH@P5'#M`!?@H.*$$.($$.&$(.
M$$(."$<+```````L````O`$``+B?__]F`0```$$.$(8"00X8@P-$#B`#70$.
M&$$.$$$."``````````<````[`$``/B@__^!`````$$.$(,":0H."$8+`E`.
M"#0````,`@``:*'__\@`````0@X0C`)!#AB&`T0.((,$5`ZP(`)Y"@X@00X8
M00X00@X(2`L`````%````$0"````HO__*@````!$#A!A#@@`%````%P"```8
MHO__1`````!$#A![#@@`)````'0"``!0HO__N0````!!#A"#`D<.L$`"G@H.
M$$$."$D+`````!0```"<`@``Z*+__P4``````````````%0```"T`@``X*+_
M_\H!````0@X0C@)"#AB-`T(.((P$00XHA@5$#C"#!D\.T"`"8@H.,$$.*$$.
M($(.&$(.$$(."$$+`HD.V"!,#N`@?0[8($$.T"`````4````#`,``%BD__\D
M``````````````!,````)`,``'"D___I`````$$.$(8"00X8@P-$#B`"60H.
M&$$.$$$."$<+8@H.&$8.$$$."$\+=PH.&$8.$$$."$(+1`X80PX000X(````
M`!P```!T`P``$*7__]L!````1`Y0`WP!"@X(2`L`````'````)0#``#0IO__
M>0````!$#B!O"@X(10L````````<````M`,``#"G__\D`````$0.$%@*#@A$
M"P```````%P```#4`P``0*?__TH!````0@X0CP)"#AB.`T4.((T$0@XHC`5'
M#C"&!D$..(,'20Z0`0*^"@XX00XP00XH0@X@0@X80@X00@X(1`MA#I@!2PZ@
M`6L.F`%!#I`!`````+0````T!```,*C__P0,````0@X0CP)"#AB.`T(.((T$
M0@XHC`5$#C"&!D$..(,'3`ZP@P(#$0(.N(,"10[`@P)Y#KB#`D(.L(,"`FP*
M#CA!#C!!#BA"#B!"#AA"#A!"#@A("P-C`0ZX@P)!#L"#`F<.N(,"00ZP@P)B
M#KB#`DL.P(,"00[(@P)$#M"#`E\.L(,"`Z4%#KB#`D(.P(,"90ZX@P)!#K"#
M`@,^`0H.N(,"20[`@P)'"P`\````[`0``(BS___X`P```$(.$(T"0@X8C`-!
M#B"&!$$.*(,%1`Y``U<""@XH00X@00X80@X00@X(20L`````-````"P%``!(
MM___;P````!!#A"&`D$.&(,#1PX@`E4*#AA!#A!!#@A!"T0.&$0.$$$."```
M```4````9`4``("W__\Z`````$0.$'$."``D````?`4``'A\__]%`@```$$.
M$(,"1`Y``[8!"@X000X(00L`````%````*0%``"`M___)P``````````````
M1````+P%``"8M___90````!"#A"/`D(.&(X#10X@C01"#BB,!4@.,(8&2`XX
M@P=/#D!P#CA!#C!!#BA"#B!"#AA"#A!"#@@`%`````0&``#`M___`@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````"`(D```````&`B0```````````````
M```!``````````$``````````0`````````%`@````````$`````````5`(`
M```````,`````````/@:0```````#0`````````T6T```````!D`````````
M\*U@```````;``````````@`````````&@````````#XK6```````!P`````
M````"`````````#U_O]O`````)@"0```````!0````````#(#4````````8`
M````````\`-````````*`````````!D%````````"P`````````8````````
M`!4````````````````````#``````````"P8````````@`````````P!@``
M`````!0`````````!P`````````7`````````,@40```````!P`````````X
M%$````````@`````````D``````````)`````````!@`````````_O__;P``
M``"X$T```````/___V\``````@````````#P__]O`````.(20```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````(KF`````````````````````````````V&T```````$8;
M0```````5AM```````!F&T```````'8;0```````AAM```````"6&T``````
M`*8;0```````MAM```````#&&T```````-8;0```````YAM```````#V&T``
M``````8<0```````%AQ````````F'$```````#8<0```````1AQ```````!6
M'$```````&8<0```````=AQ```````"&'$```````)8<0```````IAQ`````
M``"V'$```````,8<0```````UAQ```````#F'$```````/8<0```````!AU`
M```````6'4```````"8=0```````-AU```````!&'4```````%8=0```````
M9AU```````!V'4```````(8=0```````EAU```````"F'4```````+8=0```
M````QAU```````#6'4```````.8=0```````]AU````````&'D```````!8>
M0```````)AY````````V'D```````$8>0```````5AY```````!F'D``````
M`'8>0```````AAY```````"6'D```````*8>0```````MAY```````#&'D``
M`````-8>0```````YAY```````#V'D````````8?0```````%A]````````F
M'T```````#8?0```````1A]`````````````````````````````_____P``
M``"07D```````$=#0SH@*%5B=6YT=2`U+C(N,2TR-G5B=6YT=3$I(#4N,BXQ
M(#(P,34Q,3(U`$=#0SH@*%5B=6YT=2`T+CDN,BTQ,'5B=6YT=3$Q*2`T+CDN
M,@``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N
M8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I
M;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N
M<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`
M+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````
M````````````````````````````````````````````````````````````
M```````+`````0````(`````````.`)````````X`@```````!P`````````
M```````````!````````````````````$P````<````"`````````%0"0```
M````5`(````````@````````````````````!````````````````````"$`
M```'`````@````````!T`D```````'0"````````)```````````````````
M``0````````````````````T````]O__;P(`````````F`)```````"8`@``
M`````%@!````````!0`````````(````````````````````/@````L````"
M`````````/`#0```````\`,```````#8"0````````8````!````"```````
M```8`````````$8````#`````@````````#(#4```````,@-````````&04`
M``````````````````$```````````````````!.````____;P(`````````
MXA)```````#B$@```````-(`````````!0`````````"``````````(`````
M````6P```/[__V\"`````````+@30```````N!,```````"```````````8`
M```"````"````````````````````&H````$`````@`````````X%$``````
M`#@4````````D``````````%``````````@`````````&`````````!T````
M!````$(`````````R!1```````#(%````````#`&````````!0```!@````(
M`````````!@`````````?@````$````&`````````/@:0```````^!H`````
M```:````````````````````!````````````````````'D````!````!@``
M```````@&T```````"`;````````,`0``````````````````!``````````
M$`````````"$`````0````8`````````4!]```````!0'P````````@`````
M```````````````(````````````````````C0````$````&`````````&`?
M0```````8!\```````#2.P``````````````````$```````````````````
M`),````!````!@`````````T6T```````#1;````````"0``````````````
M``````0```````````````````"9`````0````(`````````0%M```````!`
M6P````````!!```````````````````(````````````````````H0````$`
M```"`````````$"<0```````0)P```````#T````````````````````!```
M`````````````````*\````!`````@`````````XG4```````#B=````````
M3`8```````````````````@```````````````````"Y````#@````,`````
M````\*U@``````#PK0````````@````````````````````(````````````
M````````Q0````\````#`````````/BM8```````^*T````````(````````
M````````````"````````````````````-$````!`````P``````````KF``
M``````"N````````"`````````````````````@```````````````````#6
M````!@````,`````````"*Y@```````(K@```````/`!````````!@``````
M```(`````````!``````````B`````$````#`````````/BO8```````^*\`
M```````(````````````````````"``````````(`````````-\````!````
M`P``````````L&````````"P````````*`(```````````````````@`````
M````"`````````#H`````0````,`````````*+)@```````HL@```````"``
M```````````````````(````````````````````[@````@````#````````
M`&"R8```````2+(```````"H$```````````````````(```````````````
M`````/,````!````,````````````````````$BR````````4@``````````
M``````````$``````````0`````````!`````P``````````````````````
J``":L@```````/P````````````````````!````````````````````
